@@ -25,14 +25,18 @@
 #' }
 
 #' @examples
+#' \dontrun{
 #' enso <- download_enso()
 #' plot(x = enso$Date, y = enso$SOI, type = "l")
+#' }
 #'
-#' @references \url{https://www.ncdc.noaa.gov/teleconnections/enso/indicators/soi/} and \url{http://www.cpc.ncep.noaa.gov/products/analysis_monitoring/ensostuff/detrend.nino34.ascii.txt}
-
 
 download_enso <- function(climate_idx = c("all", "soi", "oni","npgo"), create_csv = FALSE) {
   
+  if(!curl::has_internet()){
+    return(message("A working internet connection is required to download and import the climate indices."))
+  }
+  
   match.arg(climate_idx)
   
   if(climate_idx[1] == "soi") {
